@@ -15,11 +15,9 @@ from paste.cascade import Cascade
 from paste.registry import RegistryManager
 from paste.urlparser import StaticURLParser
 from paste.deploy.converters import asbool
-from pylons.middleware import report_libs, StatusCodeRedirect
 
 import tg
 from tg import TGApp
-from tg.error import ErrorHandler
 from tg.util import Bunch, get_partial_dict, DottedFileNameFinder
 
 from routes import Mapper
@@ -95,7 +93,6 @@ class PylonsConfigWrapper(DictMixin):
 #Create a config object that has attribute style lookup built in.
 config = PylonsConfigWrapper(pylons_config)
 
-
 class AppConfig(Bunch):
     """Class to store application configuration.
 
@@ -200,9 +197,10 @@ class AppConfig(Bunch):
         #see http://trac.turbogears.org/ticket/2247
         if asbool(config['debug']):
             warnings.simplefilter("ignore")
-            config['pylons.strict_c'] = True
+            config['pylons.strict_tmpl_context'] = True
             warnings.resetwarnings()
-            config['pylons.stritmpl_contextt_tmpl_context'] = True
+        else:
+            config['pylons.strict_tmpl_context'] = False
         self.after_init_config()
 
     def after_init_config(self):
@@ -210,14 +208,14 @@ class AppConfig(Bunch):
         Override this method to set up configuration variables at the application
         level.  This method will be called after your configuration object has
         been initialized on startup.  Here is how you would use it to override
-        the default setting of pylons.stritmpl_contextt_tmpl_context ::
+        the default setting of pylons.strict_tmpl_context ::
 
             from tg.configuration import AppConfig
             from pylons import config
 
             class MyAppConfig(AppConfig):
                 def after_init_config(self):
-                    config['pylons.stritmpl_contextt_tmpl_context'] = False
+                    config['pylons.strict_tmpl_context'] = False
 
             base_config = MyAppConfig()
 
@@ -436,7 +434,7 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
         warnings.simplefilter("ignore")
         config['pylons.strict_c'] = True
         warnings.resetwarnings()
-        config['pylons.stritmpl_contextt_tmpl_context'] = True
+        config['pylons.strict_tmpl_context'] = True
 
 
         self.render_functions.jinja = render_jinja
@@ -593,6 +591,9 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
 
     def add_error_middleware(self, global_conf, app):
         """Add middleware which handles errors and exceptions."""
+        from pylons.middleware import report_libs, StatusCodeRedirect
+        from tg.error import ErrorHandler
+
         app = ErrorHandler(app, global_conf, **config['pylons.errorware'])
 
         # Display error documents for self.handle_status_codes status codes (and
@@ -869,6 +870,11 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
             if pylons_config.get('make_body_seekable'):
                 app = maybe_make_body_seekable(app)
 
+            if 'PYTHONOPTIMIZE' in os.environ:
+                warnings.warn("Forcing full_stack=False due to PYTHONOPTIMIZE enabled. "+\
+                              "Error Middleware will be disabled", RuntimeWarning, stacklevel=2)
+                full_stack = False
+
             if asbool(full_stack):
                 if (self.auth_backend is None
                         and 401 not in self.handle_status_codes):
