@@ -41,13 +41,12 @@ class DecoratedController(object):
     controller methods for the purpose of rendering web content.
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self):
         if hasattr(self, 'allow_only') and self.allow_only is not None:
             # Let's turn Controller.allow_only into something useful for
             # the @allow_only decorator.
             predicate = self.allow_only
             #self = allow_only(predicate)(self)
-        super(DecoratedController, self).__init__(*args, **kwargs)
 
     def _is_exposed(self, controller, name):
         if hasattr(controller, name):
@@ -80,6 +79,12 @@ class DecoratedController(object):
 
         self._initialize_validation_context()
 
+        #This is necessary to prevent spurious Content Type header which would
+        #cause problems to paste.response.replace_header calls and cause
+        #responses wihout content type to get out with a wrong content type
+        if not pylons.response.headers.get('Content-Type'):
+            pylons.response.headers.pop('Content-Type', None)
+
         pylons.request.start_response = getattr(self, 'start_response', None)
 
         remainder = remainder or []
